# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import cPickle
import os
import unittest

import svn.core

from gvn.project import Project
from testing import testcommon
from testing.testcommon import RunSvn


class TestProject(unittest.TestCase):

  def setUp(self):
    self.config = testcommon.GetConfig()
    self.repo = testcommon.NewTmpRepository()
    self.repo_url = testcommon.TmpRepositoryURL()
    self.wcdir = testcommon.NewWorkingCopy()
    os.chdir(self.wcdir)
    self.assert_(os.path.isdir('./.svn'))

  def testBasic(self):
    pool = svn.core.Pool()
    p = Project(testcommon.UnittestUser(), self.repo_url + '/public/projects',
                self.config, pool)
    testcommon.GetAuthBaton(self.config, pool, p.repository)

    self.assertEquals(p.repository.URL(), self.repo_url)
    self.assertEquals(p.changebranch_base, 'changes')
    self.assertEquals(p.ChangeBranchPath(), 'changes')
    self.assertEquals(p.ChangeBranchPath('user'), 'changes/user')
    self.assertEquals(p.ChangeBranchPath('user', 'change'),
                      'changes/user/change')
    self.assertEquals(p.ChangeBranchPath('user', 'change', 'foo'),
                      'changes/user/change/foo')
    self.assertEquals(p.ChangeBranchPath('user', 'change', 'foo/bar'),
                      'changes/user/change/foo/bar')
    self.assertEquals(p.mail_template.split('\n')[2],
                      "I'd like you to do a code review."
                      '  To review this change, run')

  def testConfig(self):
    # relative change branch base
    cbb = 'Changes'
    RunSvn('ps', 'gvn:project',
           cPickle.dumps({'change-branch-base': cbb,
                          'mail-template': 'yo'}), '.')
    # Because of how Windows builds argv, we need a non-empty log message.
    RunSvn('ci', '--password', 'rayjandom', '-m', 'project test ci 1')
    pool = svn.core.Pool()
    p = Project(testcommon.UnittestUser(), self.repo_url + '/public/projects',
                self.config, pool)
    testcommon.GetAuthBaton(self.config, pool, p.repository)
    self.assertEquals(p.changebranch_base, '/'.join(['public/projects',
                                                    cbb]))
    self.assertEquals(p.mail_template, 'yo')

    # absolute change branch base
    cbb = '/Changes'
    RunSvn('ps', 'gvn:project',
           cPickle.dumps({'change-branch-base': cbb,
                          'mail-template': 'yo'}), '.')
    # Because of how Windows builds argv, we need a non-empty log message.
    RunSvn('ci', '-m', 'project test ci 2')
    pool = svn.core.Pool()
    p = Project(testcommon.UnittestUser(), self.repo_url + '/public/projects',
                self.config, pool)
    testcommon.GetAuthBaton(self.config, pool, p.repository)
    self.assertEquals(p.changebranch_base, cbb[1:])
    self.assertEquals(p.mail_template, 'yo')
